@@ -1,6 +1,6 @@
 /* Functions and data responsible for forking the inferior process.
 
-   Copyright (C) 1986-2024 Free Software Foundation, Inc.
+   Copyright (C) 1986-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -17,8 +17,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef NAT_FORK_INFERIOR_H
-#define NAT_FORK_INFERIOR_H
+#ifndef GDB_NAT_FORK_INFERIOR_H
+#define GDB_NAT_FORK_INFERIOR_H
 
 #include <string>
 #include "gdbsupport/function-view.h"
@@ -84,13 +84,12 @@ extern void gdb_flush_out_err ();
 /* Report an error that happened when starting to trace the inferior
    (i.e., when the "traceme_fun" callback is called on fork_inferior)
    and bail out.  This function does not return.  */
-extern void trace_start_error (const char *fmt, ...)
-  ATTRIBUTE_NORETURN ATTRIBUTE_PRINTF (1, 2);
+[[noreturn]] extern void trace_start_error (const char *fmt, ...)
+  ATTRIBUTE_PRINTF (1, 2);
 
 /* Like "trace_start_error", but the error message is constructed by
    combining STRING with the system error message for errno.  This
    function does not return.  */
-extern void trace_start_error_with_name (const char *string)
-  ATTRIBUTE_NORETURN;
+[[noreturn]] extern void trace_start_error_with_name (const char *string);
 
-#endif /* NAT_FORK_INFERIOR_H */
+#endif /* GDB_NAT_FORK_INFERIOR_H */
